{% extends "admin/background_pages/base.html" %} {% load bulb_static static compress %} {% block title %}Releases{% endblock title %} {% block head %} {% if DEBUG %} {% if not BULB_REQUIRES_INITIAL_PATHS %} {% compress css %} {% endcompress %} {% else %} {% endif %} {% elif not DEBUG %} {% if BULB_BUNDLED_FILES_VERSION != None %} {% with url='releases/bundle_releases_page&V='|add:BULB_BUNDLED_FILES_VERSION|add:'.css' %} {% endwith %} {% else %} {% endif %} {% endif %} {% endblock head %} {% block administration_part_name %} keyboard_arrow_right Releases {% endblock administration_part_name %} {% block content %}

## Bulb's releases

{{ releases|safe }}
{% endblock content %} {% block scripts %}{% endblock scripts %}